==> artemis-jms-client-all-2.3.0-sources.jar: org/apache/activemq/artemis/shaded/org/apache/commons/beanutils/converters/BigIntegerConverter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.shaded.org.apache.commons.beanutils.converters;

import java.math.BigInteger;

/**
 * {@link NumberConverter} implementation that handles conversion to
 * and from <b>java.math.BigInteger</b> objects.
 * <p>
 * This implementation can be configured to handle conversion either
 * by using BigInteger's default String conversion, or by using a Locale's pattern
 * or by specifying a format pattern. See the {@link NumberConverter}
 * documentation for further details.
 * <p>
 * Can be configured to either return a <i>default value</i> or throw a
 * <code>ConversionException</code> if a conversion error occurs.
 *
 * @version $Id: BigIntegerConverter.java 1540186 2013-11-08 21:08:30Z oheger $
 * @since 1.3
 */
public final class BigIntegerConverter extends NumberConverter {

    /**
     * Construct a <b>java.math.BigInteger</b> <i>Converter</i> that throws
     * a <code>ConversionException</code> if an error occurs.
     */
    public BigIntegerConverter() {
        super(false);
    }

    /**
     * Construct a <b>java.math.BigInteger</b> <i>Converter</i> that returns
     * a default value if an error occurs.
     *
     * @param defaultValue The default value to be returned
     * if the value to be converted is missing or an error
     * occurs converting the value.
     */
    public BigIntegerConverter(Object defaultValue) {
        super(false, defaultValue);
    }

    /**
     * Return the default type this <code>Converter</code> handles.
     *
     * @return The default type this <code>Converter</code> handles.
     * @since 1.8.0
     */
    @Override
    protected Class<BigInteger> getDefaultType() {
        return BigInteger.class;
    }

}

==> artemis-jms-client-all-2.6.1-sources.jar: org/apache/activemq/artemis/shaded/org/apache/commons/beanutils/converters/BigIntegerConverter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.shaded.org.apache.commons.beanutils.converters;

import java.math.BigInteger;

/**
 * {@link NumberConverter} implementation that handles conversion to
 * and from <b>java.math.BigInteger</b> objects.
 * <p>
 * This implementation can be configured to handle conversion either
 * by using BigInteger's default String conversion, or by using a Locale's pattern
 * or by specifying a format pattern. See the {@link NumberConverter}
 * documentation for further details.
 * <p>
 * Can be configured to either return a <i>default value</i> or throw a
 * <code>ConversionException</code> if a conversion error occurs.
 *
 * @version $Id: BigIntegerConverter.java 1632171 2014-10-15 20:15:17Z ggregory $
 * @since 1.3
 */
public final class BigIntegerConverter extends NumberConverter {

    /**
     * Construct a <b>java.math.BigInteger</b> <i>Converter</i> that throws
     * a <code>ConversionException</code> if an error occurs.
     */
    public BigIntegerConverter() {
        super(false);
    }

    /**
     * Construct a <b>java.math.BigInteger</b> <i>Converter</i> that returns
     * a default value if an error occurs.
     *
     * @param defaultValue The default value to be returned
     * if the value to be converted is missing or an error
     * occurs converting the value.
     */
    public BigIntegerConverter(final Object defaultValue) {
        super(false, defaultValue);
    }

    /**
     * Return the default type this <code>Converter</code> handles.
     *
     * @return The default type this <code>Converter</code> handles.
     * @since 1.8.0
     */
    @Override
    protected Class<BigInteger> getDefaultType() {
        return BigInteger.class;
    }

}
